<?php
/*************************************************************************************
 * agi.php
 * -------
 * Author: Dennis Bayer (Dennis.Bayer@mnifh-giessen.de)
 * Contributors:
 *  - M. Uli Kusterer (witness.of.teachtext@gmx.net)
 *  - Jack Lloyd (lloyd@randombit.net)
 *  - Andrew Korson (agkorson@charter.net)
 * Copyright: (c) 2004 Dennis Bayer, Nigel McNie (http://qbnz.com/highlighter)
 * Release Version: 1.0.9
 * Date Started: 2004/09/27
 *
 * AGI language file for GeSHi.
 *
 * CHANGES
 * -------
 * 2019/03/22 (1.0.9)
 *  -  Added open bracket comment, removed non-agi keywords
 * 2008/05/23 (1.0.7.22)
 *  -  Added description of extra language features (SF#1970248)
 * 2004/XX/XX (1.0.2)
 *  -  Added several new keywords (Jack Lloyd)
 * 2004/11/27 (1.0.1)
 *  -  Added StdCLib function and constant names, changed color scheme to
 *     a cleaner one. (M. Uli Kusterer)
 *  -  Added support for multiple object splitters
 * 2004/10/27 (1.0.0)
 *  -  First Release
 *
 * TODO (updated 2004/11/27)
 * -------------------------
 *
 *************************************************************************************
 *
 *     This file is part of GeSHi.
 *
 *   GeSHi is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or
 *   (at your option) any later version.
 *
 *   GeSHi is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with GeSHi; if not, write to the Free Software
 *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 ************************************************************************************/

$language_data = array (
    'LANG_NAME' => 'AGI',
    'COMMENT_SINGLE' => array(1 => '//', 2 => '['), //, 2 => '#'
    'COMMENT_MULTI' => array('/*' => '*/'),
    'COMMENT_REGEXP' => array(),
    'CASE_KEYWORDS' => GESHI_CAPS_NO_CHANGE,
    'QUOTEMARKS' => array('"'),
    'HARDQUOTE' => array("'", "'"),
    'ESCAPE_CHAR' => array(),
    'ESCAPE_REGEXP' => array(),
        //Simple Single Char Escapes
        //1 => "#\\\\[\\\\abfnrtv\'\"?\n]#i",
        //Hexadecimal Char Specs
        //2 => "#\\\\x[\da-fA-F]{2}#",
        //Hexadecimal Char Specs
        //3 => "#\\\\u[\da-fA-F]{4}#",
        //Hexadecimal Char Specs
        //4 => "#\\\\U[\da-fA-F]{8}#",
        //Octal Char Specs
        //5 => "#\\\\[0-7]{1,3}#"
        //),
    'NUMBERS' =>
        GESHI_NUMBER_INT_BASIC | GESHI_NUMBER_INT_CSTYLE | GESHI_NUMBER_BIN_PREFIX_0B |
        GESHI_NUMBER_OCT_PREFIX | GESHI_NUMBER_HEX_PREFIX | GESHI_NUMBER_HEX_SUFFIX | GESHI_NUMBER_FLT_NONAGI |
        GESHI_NUMBER_FLT_NONAGI_F | GESHI_NUMBER_FLT_AGI_SHORT | GESHI_NUMBER_FLT_AGI_ZERO,
    'KEYWORDS' => array(
        1 => array(
            'else', 'if', 'goto', 
            ),
//       1 => array(
//           'and', 'break', 'default', 'define', 'do', 'else', 'for', 'if', 'instance', 'include', 'method', 
//           'not', 'of', 'or', 'preload', 'procedure', 'properties', 'rest', 'return', 'script', 'send', 'switch',
//           'use', 'var', 'while', 
//           ),
//        2 => array(
//            'asm', 'case', 'class', 'local', 'public', 'self',  'super',
//            ),
//        3 => array(
//            'objectName', 'objectSpecies', 'objectSuperclass', 'objectFunctionArea', 'objectInfo', 
//            'objectLocal', 'objectSize', 'objectTotalProperties', 'objectType', 'string', 
            ),
        ),
    'SYMBOLS' => array(
        0 => array('(', ')', '{', '}', '[', ']'),
        1 => array('<', '>','='),
        2 => array('+', '-', '*', '/', '%'),
        3 => array('!', '^', '&', '|', '@', '#'),
        4 => array('?', ';'), //, ':'
        5 => array('$', '0', '1', '2', '3', '4', '5', '6', '7', '8', '9', 
		'0a', '1a', '2a', '3a', '4a', '5a', '6a', '7a', '8a', '9a', 
		'0A', '1A', '2A', '3A', '4A', '5A', '6A', '7A', '8A', '9A', 
		'0f', '1f', '2f', '3f', '4f', '5f', '6f', '7f', '8f', '9f', 
		'0F', '1F', '2F', '3F', '4F', '5F', '6F', '7F', '8F', '9F',)
        ),
    'CASE_SENSITIVE' => array(),
    //    GESHI_COMMENTS => false,
    //    1 => true,
    //    2 => true,
    //    3 => true,
    //    4 => true,
    //    ),
    'STYLES' => array(
        'KEYWORDS' => array(
            1 => 'color: #0000ff;',
 //           2 => 'color: #0000ff;',
 //           3 => 'color: #0000ff;', //0000dd
 //           4 => 'color: #0000ff;',
            ),
        'COMMENTS' => array(
            1 => 'color: #999999; font-style: italic;' //, background-color: #00FFFF; 
            2 => 'color: #999999; font-style: italic;' //, background-color: #00FFFF; 
            'MULTI' => 'color: #999999; font-style: italic; font-style: italic;' // 'color: #000080; background-color: #00FFFF;
            ),
        'ESCAPE_CHAR' => array(),
        //   0 => 'color: #800080; font-weight: bold;',
        //    1 => 'color: #800080; font-weight: bold;',
        //    2 => 'color: #800080; font-weight: bold;',
        //    3 => 'color: #800080; font-weight: bold;',
        //    4 => 'color: #800080; font-weight: bold;',
        //    5 => 'color: #800080; font-weight: bold;',
        //    'HARD' => '',
        //    ),
        'BRACKETS' => array(
            0 => 'color: #006633;'
            ),
        'STRINGS' => array(
            0 => 'color: #CC0033;',
            'HARD' => 'color: #FF6600;'
            ),
        'NUMBERS' => array(
            0 => 'color: #000099;',
            GESHI_NUMBER_BIN_PREFIX_0B => 'color: #000099;',
            GESHI_NUMBER_OCT_PREFIX => 'color: #000099;',
            GESHI_NUMBER_HEX_PREFIX => 'color: #000099;',
            GESHI_NUMBER_FLT_AGI_SHORT => 'color:#000099;',
            GESHI_NUMBER_FLT_AGI_ZERO => 'color:#000099;',
            GESHI_NUMBER_FLT_NONAGI_F => 'color:#000099;',
            GESHI_NUMBER_FLT_NONAGI => 'color:#000099;'
            ),
        'METHODS' => array(
            1 => 'color: #007788;',
            2 => 'color: #007788;'
            ),
        'SYMBOLS' => array(
            0 => 'color: #006633;', //00290B
            1 => 'color: #006633; font-weight: bold;',
            2 => 'color: #006633; font-weight: bold;',
            3 => 'color: #006633; font-weight: bold;',
            4 => 'color: #006633; font-weight: bold;',
            5 => 'color: #000099;'
            ),
        'REGEXPS' => array(),
        //    ),
        'SCRIPT' => array(),
        //    )
        ),
    'URLS' => array(
        1 => '',
        2 => '',
        3 => '',
        4 => ''
        ),
    'OOLANG' => true,
    'OBJECT_SPLITTERS' => array(),
    //    1 => '.',
    //    2 => '::'
    //    ),
    'REGEXPS' => array(
        ),
    'STRICT_MODE_APPLIES' => GESHI_NEVER,
    'SCRIPT_DELIMITERS' => array(
        ),
    'HIGHLIGHT_STRICT_BLOCK' => array(),
    //    ),
    'TAB_WIDTH' => 4,
    'PARSER_CONTROL' => array(
        'KEYWORDS' => array(
            'DISALLOWED_BEFORE' => "(?<![a-zA-Z0-9\_\|\#])",
            'DISALLOWED_AFTER' => "(?![a-zA-Z0-9_\|%\\-])"
        )
    )
);

?>